<?php
/**
 * @file
 * Theme functions for Group Mind Q&A.
 */

/**
 * Implements hook_theme().
 *
 * Overwrite templates to put ours.
 */
function group_mind_q_a_theme() {
  return array(
    'rate_template_q_a_vote_number_up_down' => array(
      'variables' => array(
        'links' => NULL,
        'results' => NULL,
        'mode' => NULL,
        'just_voted' => FALSE,
        'content_type' => NULL,
        'content_id' => NULL,
        'display_options' => NULL),
      'template' => 'qa-number-up-down',
    ),
  );
}

/**
 * Implements hook_theme_registery_alter().
 *
 * Force to use templates of the module.
 */
function group_mind_q_a_theme_registry_alter(&$theme_registry) {
  $theme_registry_copy = $theme_registry;
  $module_path = drupal_get_path('module', 'group_mind_q_a');
  _theme_process_registry($theme_registry_copy, 'phptemplate', 'theme_engine', 'qa_theme', $module_path);
  $theme_registry += array_diff_key($theme_registry_copy, $theme_registry);
  // A list of templates the module will provide templates for.
  $hooks = array('node', 'comment');
  foreach ($hooks as $hook) {
    // Add the key 'theme paths' if it doesn't exist in this theme's registry.
    if (!isset($theme_registry[$hook]['theme paths'])) {
      $theme_registry[$hook]['theme paths'] = array();
    }
    // Shift this module's directory to the top of the theme path list.
    if (is_array($theme_registry[$hook]['theme paths'])) {
      $first_element = array_shift($theme_registry[$hook]['theme paths']);
      if ($first_element) {
        array_unshift($theme_registry[$hook]['theme paths'], $first_element, $module_path);
      }
      else {
        array_unshift($theme_registry[$hook]['theme paths'], $module_path);
      }
    }
  }
}

/**
 * Implements hook_views_pre_view().
 *
 * Alter The Q&A views.
 */
function group_mind_q_a_views_pre_view(&$view, &$display_id, &$args) {
  // If the view of Q&A is rendered we need to add our CSS.
  if ($view->name == 'gm_q_a' && $display_id == 'page_qa') {
    drupal_add_css(drupal_get_path('module', 'group_mind_q_a') . '/css/qa-commons.css');
    drupal_add_css(drupal_get_path('module', 'group_mind_q_a') . '/css/qa-view.css');
    // Drupal_add_js(array('group_mind_q_a' =>
    // array('last_nid_question' => 'value')), 'setting');.
    // Get the last nid question . We put that in JS to know
    // if we need to prevent the user that there is new questions available.
    $query = new EntityFieldQuery();
    $query->entityCondition('entity_type', 'node')
        ->entityCondition('bundle', 'question')
        ->propertyCondition('status', 1)
        ->propertyOrderBy('nid', 'DESC')
        ->range(0, 1);
    $result = $query->execute();
    if (!empty($result['node'])) {
      $last_nid_question = @reset(array_keys($result['node']));
      drupal_add_js(array('group_mind_q_a' => array('last_nid_question' => $last_nid_question)), array('type' => 'setting', 'scope' => JS_DEFAULT));
      drupal_add_js(drupal_get_path('module', 'group_mind_q_a') . '/js/group_mind_q_a_new_questions.js');
    }
  }

}


/**
 * Implements hook_node_view().
 *
 * Alter the question view.
 */
function group_mind_q_a_node_view($node, $view_mode, $langcode) {

  if ($node->type == 'question') {
    // Load CSS.
    drupal_add_css(drupal_get_path('module', 'group_mind_q_a') . '/css/qa-commons.css');
    drupal_add_css(drupal_get_path('module', 'group_mind_q_a') . '/css/qa.css');
  }

}

/**
 * Preprocess function for the rate template.
 */
function group_mind_q_a_preprocess_rate_template_commons_thumbs_up_down(&$variables) {
  extract($variables);

  $up_classes = 'rate-number-up-down-btn-up';
  $down_classes = 'rate-number-up-down-btn-down';
  if (isset($results['user_vote'])) {
    switch ($results['user_vote']) {
      case $links[0]['value']:
        $up_classes .= ' rate-voted';
        break;

      case $links[1]['value']:
        $down_classes .= ' rate-voted';
        break;

    }
  }

  $variables['up_button'] = theme('rate_button', array(
    'text' => array(
      'text' => $links[0]['text'],
      'href' => $links[0]['href'],
      'class' => $up_classes,
    )));
  $variables['down_button'] = theme('rate_button', array(
    'text' => array(
      'text' => $links[1]['text'],
      'href' => $links[1]['href'],
      'class' => $down_classes,
    )));
  if ($results['rating'] > 0) {
    $score = $results['rating'];
    $score_class = 'positive';
  }
  elseif ($results['rating'] < 0) {
    $score = $results['rating'];
    $score_class = 'negative';
  }
  else {
    $score = 0;
    $score_class = 'neutral';
  }
  $variables['score'] = $score;
  $variables['score_class'] = $score_class;

  $info = array();
  if ($mode == RATE_CLOSED) {
    $info[] = t('Voting is closed.');
  }
  if ($mode != RATE_COMPACT && $mode != RATE_COMPACT_DISABLED) {
    if (isset($results['user_vote'])) {
      $info[] = t("You voted '@option'.", array('@option' => $results['user_vote'] == 1 ? $links[0]['text'] : $links[1]['text']));
    }
  }
  $variables['info'] = implode(' ', $info);
}
