<?php
/**
 * @file
 * The answers class.
 */

class answers {

  /**
   * Get answers of a question sort by vote.
   *
   * @param int $question_id
   *   The node id of the question.
   *
   * @return array
   *   Array of answers.
   */
  static public function get($question_id) {
    // Load answers with vote positive.
    $query = db_select('field_data_field_related_question', 'rq');
    $query->condition('field_related_question_target_id', $question_id, '=');
    $query->join('node', 'n', 'rq.entity_id = n.nid');
    // Status publish if it's not an admin (else, the admin can see everything).
    if (!user_access('administer nodes')) {
      $query->condition('n.status', 1, '=');
    }

    $query->leftjoin('votingapi_vote', 'v', 'rq.entity_id = v.entity_id');
    $query->addExpression('COALESCE(SUM(v.value), 0)', 'points');
    // OR.
    $or = db_or();
    $or->condition('v.tag', 'vote', '=');
    $or->isNull('v.tag');
    $or2 = db_or();
    $or2->condition('v.entity_type', 'node', '=');
    $or2->isNull('v.entity_type');
    $query->condition($or);
    $query->condition($or2);
    $query->groupby('rq.entity_id');
    $query->orderBy('points', 'DESC');
    $query->orderBy('n.created', 'DESC');
    $query->fields('rq', array('entity_id'));
    $result = $query->execute();

    $answers = array();

    // Record positive answers.
    while ($record = $result->fetchAssoc()) {
      $answers[$record['entity_id']] = node_load($record['entity_id']);
    }

    return $answers;

  }

  /**
   * Generate the answer form.
   *
   * @param object $question_node
   *   The question node.
   */
  static public function generate_answer_form($question_node) {
    global $user;
    $answer_node = (object) array(
      'uid' => $user->uid,
      'name' => (isset($user->name) ? $user->name : ''),
      'type' => 'answer',
      'language' => LANGUAGE_NONE,
      'field_related_question' => array(LANGUAGE_NONE => array(array('target_id' => $question_node->nid))),
    );

    $form_state['build_info']['args'] = array($answer_node);
    $form_state['redirect'] = 'node/' . $question_node->nid;
    // Force the answer to be attached to this question and coming back here
    // when we submit a comment.
    $_GET['field_related_question'] = $_GET['destination'] = $question_node->nid;
    form_load_include($form_state, 'inc', 'node', 'node.pages');
    $answer_form = drupal_build_form('answer_node_form', $form_state);
    $answer_form['field_related_question']['#access'] = FALSE;
    $answer_form['title_field'][LANGUAGE_NONE][0]['value']['#value'] = '[ANSWER] ' . $question_node->title;
    $answer_form['title_field'][LANGUAGE_NONE][0]['value']['#type'] = 'hidden';
    $answer_form['title_field'][LANGUAGE_NONE][0]['value']['#required'] = FALSE;

    return $answer_form;
  }
}
